@@ -41,6 +41,7 @@ http://talk.maemo.org/showthread.php?t=39177
 //main settings window
 #define NON_GTK_RESPONSE_ADD_CMD 10
 #define NON_GTK_RESPONSE_EDIT_CMD 20
+#define NON_GTK_RESPONSE_GET_CMDS 30
 //save is GTK_RESPONSE_OK
 
 //Add/Edit/Delete window
@@ -96,6 +97,10 @@ struct _DesktopCmdExecPrivate
 	//instance data
 		gboolean updOnClick;
 		gboolean updOnDesktop;
+		gboolean updOnBoot;
+
+		gboolean flagBooted;
+		
 		guint updNeworkPolicy;
 		gdouble widthRatio;
 		gdouble heightRatio;//AP
@@ -263,6 +268,14 @@ void desktop_cmd_exec_read_settings ( DesktopCmdExec *self )
 				error = NULL;
 			}
 
+			self->priv->updOnBoot = g_key_file_get_boolean (keyFile, self->priv->widgetID, "updOnBoot", &error);
+			if (error) {
+
+				noInstanceKeysFlag = FALSE;
+				g_error_free (error);
+				error = NULL;
+			}
+
 			self->priv->delayIndex = (guint) g_key_file_get_integer (keyFile, self->priv->widgetID, "delayIndex", &error);
 			if (error) {
 
@@ -298,6 +311,7 @@ void desktop_cmd_exec_read_settings ( DesktopCmdExec *self )
 	{
 		self->priv->updOnClick = TRUE;
 		self->priv->updOnDesktop = TRUE;
+		self->priv->updOnBoot = TRUE;
 		self->priv->updNeworkPolicy = NETWORK__UNRELATED;
 		self->priv->delayIndex = 0;
 		self->priv->delaySeconds = 0;
@@ -363,7 +377,7 @@ void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean newAll, gbo
 		"hal-device bme | grep battery.reporting | awk -F. '{print $3}' | sort | awk '$1 == \"current\" { current = $3}; $1== \"design\" {print current \"/\" $3}'",
 		"cat /proc/bootreason",
 		"cat /var/lib/dsme/boot_count",
-		"wget -q -O - api.myiptest.com | awk -F \"\\\"\" '{print $4}'",
+		"wget --timeout=10 -q -O - api.myiptest.com | awk -F \"\\\"\" '{print $4}'",
 		"/sbin/ifconfig | grep \"inet addr\" | awk -F: '{print $2}' | awk '{print $1}'",
 		"df | awk '$1 == \"rootfs\" {print $5}'",
 		"df -h | awk ' $1 == \"rootfs\" {print $4\"B\"}'", NULL};
@@ -396,6 +410,7 @@ void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean newAll, gbo
 		self->priv->displayTitle = TRUE;
 		self->priv->updOnClick = TRUE;
 		self->priv->updOnDesktop = TRUE;
+		self->priv->updOnBoot = TRUE;
 		self->priv->updNeworkPolicy = NETWORK__UNRELATED;
 		self->priv->delayIndex = 0;
 	}
@@ -420,6 +435,7 @@ void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean newAll, gbo
 	g_key_file_set_boolean (keyFile, self->priv->widgetID, "displayTitle", self->priv->displayTitle);
 	g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnClick", self->priv->updOnClick);
 	g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnDesktop", self->priv->updOnDesktop);
+	g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnBoot", self->priv->updOnBoot);
 	g_key_file_set_integer (keyFile, self->priv->widgetID, "delayIndex", self->priv->delayIndex);
 	g_key_file_set_integer (keyFile, self->priv->widgetID, "updNeworkPolicy", self->priv->updNeworkPolicy);
 	
@@ -547,9 +563,13 @@ void desktop_cmd_exec_content_create (DesktopCmdExec *self)
 	gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), self->priv->contents, FALSE, FALSE, 0);
 
 	//widget drawing signal connections
-	g_signal_connect (self->priv->contents, "button-release-event", G_CALLBACK (desktop_cmd_exec_button_release), self);
-	g_signal_connect (self->priv->contents, "button-press-event", G_CALLBACK (desktop_cmd_exec_button_press), self);
-	g_signal_connect (self->priv->contents, "leave-notify-event", G_CALLBACK (desktop_cmd_exec_leave_event), self);
+// 	g_signal_connect (self->priv->contents, "button-release-event", G_CALLBACK (desktop_cmd_exec_button_release), self);
+// 	g_signal_connect (self->priv->contents, "button-press-event", G_CALLBACK (desktop_cmd_exec_button_press), self);
+// 	g_signal_connect (self->priv->contents, "leave-notify-event", G_CALLBACK (desktop_cmd_exec_leave_event), self);
+
+	g_signal_connect (GTK_WIDGET (self), "button-release-event", G_CALLBACK (desktop_cmd_exec_button_release), self);
+	g_signal_connect (GTK_WIDGET (self), "button-press-event", G_CALLBACK (desktop_cmd_exec_button_press), self);
+	g_signal_connect (GTK_WIDGET (self), "leave-notify-event", G_CALLBACK (desktop_cmd_exec_leave_event), self);
 	
 	gtk_widget_show_all (self->priv->homeWidget);
 	gtk_widget_show (self->priv->cmdTitle_lb);
@@ -595,7 +615,6 @@ gboolean desktop_cmd_exec_update_content (DesktopCmdExec *self)
 	
 	if(self->priv->updNeworkPolicy == NETWORK__ONLY_DISCONNECTED && self->priv->isConnected == TRUE)
 		return FALSE;
-
 	
 	FILE *fp;
 	gchar line[2048];
@@ -616,20 +635,28 @@ gboolean desktop_cmd_exec_update_content (DesktopCmdExec *self)
 	else
 		gtk_label_set_text (GTK_LABEL (self->priv->cmdTitle_lb), "");
 
-	fp = popen (self->priv->instanceCmd, "r");
+	if(self->priv->flagBooted || self->priv->updOnBoot)
+	{
+		fp = popen (self->priv->instanceCmd, "r");
+		
+		/* AP; No!No!No!Yes!, thanks! */
+		//	while (fgets (line, sizeof line, fp)) {//Needed to change this "line-based" management for output //AP
+		if (l=fread (line, 1, sizeof line, fp)) {//to this "buffer-based" for multiline handling in widget //AP
+			line[l-1]='\000';//AP
+			
+			gtk_label_set_text (GTK_LABEL (self->priv->cmdResult_lb), line);//AP
+			found = TRUE;
+		}
+		pclose (fp);
 
-	/* AP; No!No!No!Yes!, thanks! */
-	//	while (fgets (line, sizeof line, fp)) {//Needed to change this "line-based" management for output //AP
-	if (l=fread (line, 1, sizeof line, fp)) {//to this "buffer-based" for multiline handling in widget //AP
-		line[l-1]='\000';//AP
-
-		gtk_label_set_text (GTK_LABEL (self->priv->cmdResult_lb), line);//AP
-		found = TRUE;
+		if (!found) {
+			gtk_label_set_text (GTK_LABEL (self->priv->cmdResult_lb), "Invalid Command");
+		}
 	}
-	pclose (fp);
-	
-	if (!found) {
-		gtk_label_set_text (GTK_LABEL (self->priv->cmdResult_lb), "Invalid Command");
+	else
+	{
+		self->priv->flagBooted = TRUE;
+		gtk_label_set_text (GTK_LABEL (self->priv->cmdResult_lb), "");
 	}
 
 	if( (self->priv->updateTimerID == 0) && (self->priv->delaySeconds > 0))
@@ -770,6 +797,8 @@ static void desktop_cmd_exec_init (DesktopCmdExec *self)
 
 	self->priv->widgetID = NULL;
 
+	self->priv->flagBooted = FALSE;
+
 	self->priv->connection = con_ic_connection_new ();
 	g_signal_connect (self->priv->connection, "connection-event", G_CALLBACK (desktop_cmd_exec_connection_event), self);
 	g_object_set (self->priv->connection, "automatic-connection-events", TRUE);
@@ -827,6 +856,7 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 																										 _("wdgt_bd_save"), GTK_RESPONSE_ACCEPT,
 																										 "Add Cmd", NON_GTK_RESPONSE_ADD_CMD,
 																										 "Edit Cmd", NON_GTK_RESPONSE_EDIT_CMD,
+																										 "Scripts Wiki", NON_GTK_RESPONSE_GET_CMDS,
 																										 NULL);
 
 // 		GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
@@ -853,13 +883,25 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 		
 		GtkWidget *selector = hildon_touch_selector_new_text ();
 		int i;
+		int cmdOnListMatch = -1;
 		for(i=0;i<self->priv->c_size;i++)
 		{
 			hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), self->priv->c_titles[i]);
 			if(g_strcmp0(self->priv->c_titles[i],self->priv->instanceTitle) == 0)
-				if(g_strcmp0(self->priv->c_commands[i],self->priv->instanceCmd) == 0)
+			{
+// 				if(g_strcmp0(self->priv->c_commands[i],self->priv->instanceCmd) == 0)
+// 				{
 					hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, i);
+					cmdOnListMatch = i;
+// 				}
+			}
 		}
+		if(cmdOnListMatch < 0)
+		{
+			hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "Not found, pick on list!");
+			hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, self->priv->c_size);
+		}
+		
 		
 		GtkWidget * cmdSelector = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
 		hildon_button_set_title (HILDON_BUTTON (cmdSelector), "Commands: ");
@@ -926,6 +968,11 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 		GtkWidget *updPolicyLabel = gtk_label_new ("");
 		gtk_label_set_markup (GTK_LABEL (updPolicyLabel), "<small>Update Policy:</small>");
 		gtk_container_add (GTK_CONTAINER (content_area), updPolicyLabel);
+
+		GtkWidget *checkBtBoot = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+		gtk_button_set_label (GTK_BUTTON (checkBtBoot), "Update on Boot");
+		gtk_container_add (GTK_CONTAINER (content_area), checkBtBoot);
+		hildon_check_button_set_active (HILDON_CHECK_BUTTON (checkBtBoot), self->priv->updOnBoot);
 		
 		GtkWidget *checkBtClick = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
 		gtk_button_set_label (GTK_BUTTON (checkBtClick), "Update when clicked");
@@ -938,7 +985,7 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 		hildon_check_button_set_active (HILDON_CHECK_BUTTON (checkBtDesktop), self->priv->updOnDesktop);
 
 		GtkWidget *intervalSelector = hildon_touch_selector_new_text ();
-		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (intervalSelector), "0");
+		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (intervalSelector), "Disabled");
 		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (intervalSelector), "30 Seconds");
 		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (intervalSelector), "1 Minute");
 		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (intervalSelector), "5 Minutes");
@@ -958,10 +1005,10 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 		gtk_container_add (GTK_CONTAINER (content_area), intervalSelBt);
 
 		
-		GtkWidget *updIntervalLabel = gtk_label_new ("");
-		gtk_label_set_markup (GTK_LABEL (updIntervalLabel), "<small>'0' disables periodic updating.</small>");
-		gtk_misc_set_alignment (GTK_MISC (updIntervalLabel), 0, 0);
-		gtk_container_add (GTK_CONTAINER (content_area), updIntervalLabel);
+// 		GtkWidget *updIntervalLabel = gtk_label_new ("");
+// 		gtk_label_set_markup (GTK_LABEL (updIntervalLabel), "<small>'0' disables periodic updating.</small>");
+// 		gtk_misc_set_alignment (GTK_MISC (updIntervalLabel), 0, 0);
+// 		gtk_container_add (GTK_CONTAINER (content_area), updIntervalLabel);
 
 
 		GtkWidget *networkPolicySel = hildon_touch_selector_new_text ();
@@ -993,7 +1040,7 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 		int setDialogReturn = 0;
 
 		setDialogReturn = gtk_dialog_run (GTK_DIALOG (dialog));
-		if (setDialogReturn == GTK_RESPONSE_ACCEPT)
+		if (setDialogReturn == GTK_RESPONSE_ACCEPT || setDialogReturn == NON_GTK_RESPONSE_EDIT_CMD)
 		{
 			int cmdSel = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (selector), 0);
 			if(cmdSel < self->priv->c_size && cmdSel >= 0)
@@ -1014,6 +1061,7 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 			
 			self->priv->updOnClick = hildon_check_button_get_active (HILDON_CHECK_BUTTON (checkBtClick));
 			self->priv->updOnDesktop = hildon_check_button_get_active (HILDON_CHECK_BUTTON (checkBtDesktop));
+			self->priv->updOnBoot = hildon_check_button_get_active (HILDON_CHECK_BUTTON (checkBtBoot));
 			
 			self->priv->delayIndex = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (intervalSelector), 0);
 			self->priv->delaySeconds = GetSeconds(self->priv->delayIndex);
@@ -1026,15 +1074,28 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 			}
 
 			desktop_cmd_exec_write_settings (self, FALSE, FALSE);
+		}
+
+		if (setDialogReturn == GTK_RESPONSE_ACCEPT)
+		{
 			desktop_cmd_exec_update_content (self);
 			settingsRunning = 0;
 		}
-		else if(setDialogReturn == NON_GTK_RESPONSE_ADD_CMD)
+
+		if(setDialogReturn == NON_GTK_RESPONSE_GET_CMDS)
+		{
+			system("dbus-send --system --type=method_call --dest='com.nokia.osso_browser' /com/nokia/osso_browser/request com.nokia.osso_browser.open_new_window string:'http://wiki.maemo.org/Desktop_Command_Execution_Widget_scripts'");
+			desktop_cmd_exec_update_content (self);
+			settingsRunning = 0;
+		}
+
+		if(setDialogReturn == NON_GTK_RESPONSE_ADD_CMD)
 		{
 			desktop_cmd_exec_edit_add_dialog(self, TRUE, 0);
 			desktop_cmd_exec_write_settings (self, FALSE, FALSE);
 		}
-		else if(setDialogReturn == NON_GTK_RESPONSE_EDIT_CMD)
+
+		if(setDialogReturn == NON_GTK_RESPONSE_EDIT_CMD)
 		{
 			int cmdSel = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (selector), 0);
 			if(cmdSel < self->priv->c_size && cmdSel >= 0)
@@ -1082,7 +1143,11 @@ void desktop_cmd_exec_edit_add_dialog ( DesktopCmdExec *self, gboolean new, gint
 	gtk_box_pack_start (GTK_BOX (titleBox), titleLabel, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (titleBox), titleEntry, TRUE, TRUE, 0);
 	if(!new)
+	{
 		hildon_entry_set_text(HILDON_ENTRY (titleEntry), self->priv->c_titles[curr]);
+		gtk_widget_set_sensitive(GTK_WIDGET(titleEntry), FALSE);
+	}
+	
 	
 	gtk_container_add (GTK_CONTAINER (content_area), titleBox);
 	//END
@@ -1096,6 +1161,13 @@ void desktop_cmd_exec_edit_add_dialog ( DesktopCmdExec *self, gboolean new, gint
 	gtk_size_group_add_widget (group, commandLabel);
 	
 	GtkWidget *commandEntry = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	//BEGIN Disable automatic capitalisation
+	HildonGtkInputMode input_mode = hildon_gtk_entry_get_input_mode (GTK_ENTRY (commandEntry));
+	input_mode &= ~HILDON_GTK_INPUT_MODE_AUTOCAP;
+	//input_mode &= ~(HILDON_GTK_INPUT_MODE_AUTOCAP | HILDON_GTK_INPUT_MODE_DICTIONARY);
+	hildon_gtk_entry_set_input_mode (GTK_ENTRY (commandEntry), input_mode);
+	//END: Disable automatic capitalisation
+	
 	gtk_box_pack_start (GTK_BOX (commandBox), commandLabel, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (commandBox), commandEntry, TRUE, TRUE, 0);
 	if(!new)
@@ -1185,6 +1257,18 @@ void EditCommand(DesktopCmdExec *self, gchar * s_title, gchar * s_command, int i
 
 	self->priv->c_titles[index] = s_title;
 	self->priv->c_commands[index] = s_command;
+	/*
+	........ check the thing
+	self->priv->c_titles[index] = s_title;
+	self->priv->c_commands[index] = s_command;
+	//vvvv BUG try to fix bug when NULL selector when back from command edit
+	g_free(self->priv->instanceTitle);
+	g_free(self->priv->instanceCmd);
+	self->priv->instanceTitle = g_strdup(s_title);
+	self->priv->instanceCmd = g_strdup(s_command);
+	//^^^^ BUG try to fix bug when NULL selector when back from command edit
+	
+	*/
 }
 
 void DelCommand(DesktopCmdExec *self, int index)
